@@ -66,8 +66,7 @@ class Plinux:
         self.port = port
         self.username = username
         self.password = password
-        self.logger = plogger.logger(self.__class__.__name__)
-        self.logger.disabled = not logger_enabled
+        self.logger = plogger.logger(self.__class__.__name__, enabled=logger_enabled)
 
     def __str__(self):
         return f'Local host: {self.get_current_os_name()}\n' \
